@@ -5,6 +5,8 @@
  - Licensed under the GNU GPL version 3 or higher.
  -}
 
+{-# LANGUAGE CPP #-}
+
 module Annex.LockPool where
 
 import qualified Data.Map as M
@@ -12,24 +14,33 @@ import System.Posix.Types (Fd)
 
 import Common.Annex
 import Annex
+import Annex.Perms
 
 {- Create a specified lock file, and takes a shared lock. -}
 lockFile :: FilePath -> Annex ()
 lockFile file = go =<< fromPool file
-	where
-		go (Just _) = return () -- already locked
-		go Nothing = do
-			fd <- liftIO $ openFd file ReadOnly (Just stdFileMode) defaultFileFlags
-			liftIO $ waitToSetLock fd (ReadLock, AbsoluteSeek, 0, 0)
-			changePool $ M.insert file fd
+  where
+	go (Just _) = noop -- already locked
+	go Nothing = do
+#ifndef mingw32_HOST_OS
+		mode <- annexFileMode
+		fd <- liftIO $ noUmask mode $
+			openFd file ReadOnly (Just mode) defaultFileFlags
+		liftIO $ waitToSetLock fd (ReadLock, AbsoluteSeek, 0, 0)
+#else
+		liftIO $ writeFile file ""
+		let fd = 0
+#endif
+		changePool $ M.insert file fd
 
 unlockFile :: FilePath -> Annex ()
-unlockFile file = go =<< fromPool file
-	where
-		go Nothing = return ()
-		go (Just fd) = do
-			liftIO $ closeFd fd
-			changePool $ M.delete file
+unlockFile file = maybe noop go =<< fromPool file
+  where
+	go fd = do
+#ifndef mingw32_HOST_OS
+		liftIO $ closeFd fd
+#endif
+		changePool $ M.delete file
 
 getPool :: Annex (M.Map FilePath Fd)
 getPool = getState lockpool
