@@ -10,6 +10,7 @@ module Backend.WORM (backends) where
 import Common.Annex
 import Types.Backend
 import Types.Key
+import Types.KeySource
 
 backends :: [Backend]
 backends = [backend]
@@ -19,6 +20,7 @@ backend = Backend
 	{ name = "WORM"
 	, getKey = keyValue
 	, fsckKey = Nothing
+	, canUpgradeKey = Nothing
 	}
 
 {- The key includes the file size, modification time, and the
