@@ -57,6 +57,9 @@ import qualified Command.Ungroup
 import qualified Command.Vicfg
 import qualified Command.Sync
 import qualified Command.AddUrl
+#ifdef WITH_FEED
+import qualified Command.ImportFeed
+#endif
 import qualified Command.RmUrl
 import qualified Command.Import
 import qualified Command.Map
@@ -91,6 +94,9 @@ cmds = concat
 	, Command.Lock.def
 	, Command.Sync.def
 	, Command.AddUrl.def
+#ifdef WITH_FEED
+	, Command.ImportFeed.def
+#endif
 	, Command.RmUrl.def
 	, Command.Import.def
 	, Command.Init.def
