@@ -582,9 +582,10 @@ test_unused env = "git-annex unused/dropunused" ~: intmpclonerepoInDirect env $
 		@? "dropkey failed"
 	checkunused [sha1annexedfilekey] ("after dropkey --force " ++ Types.Key.key2file annexedfilekey)
 
-	git_annex env "dropunused" ["1"] @? "dropunused failed"
+	not <$> git_annex env "dropunused" ["1"] @? "dropunused failed to fail without --force"
+	git_annex env "dropunused" ["--force", "1"] @? "dropunused failed"
 	checkunused [] "after dropunused"
-	not <$> git_annex env "dropunused" ["10", "501"] @? "dropunused failed to fail on bogus numbers"
+	not <$> git_annex env "dropunused" ["--force", "10", "501"] @? "dropunused failed to fail on bogus numbers"
 
   where
 	checkunused expectedkeys desc = do
@@ -642,14 +643,11 @@ test_version env = "git-annex version" ~: intmpclonerepo env $ do
 
 test_sync :: TestEnv -> Test
 test_sync env = "git-annex sync" ~: intmpclonerepo env $ do
-{- For unknown reasons, running sync in the test suite on Windows
- - fails with what looks like PATH errors. sync works outside
- - the test suite though. TODO -}
-#ifndef __WINDOWS__
 	git_annex env "sync" [] @? "sync failed"
-#else
-	noop
-#endif
+	{- Regression test for bug fixed in 
+	 - 7b0970b340d7faeb745c666146c7f701ec71808f, where in direct mode
+	 - sync committed the symlink standin file to the annex. -}
+	git_annex_expectoutput env "find" ["--in", "."] []
 
 {- Regression test for union merge bug fixed in
  - 0214e0fb175a608a49b812d81b4632c081f63027 -}
@@ -1112,7 +1110,7 @@ prepare forcedirect = do
 
 	let env =
 		-- Ensure that the just-built git annex is used.
-		[ ("PATH", cwd ++ ":" ++ p)
+		[ ("PATH", cwd ++ [searchPathSeparator] ++ p)
 		, ("TOPDIR", cwd)
 		-- Avoid git complaining if it cannot determine the user's
 		-- email address, or exploding if it doesn't know the user's
