@@ -5,13 +5,21 @@
  - Licensed under the GNU GPL version 3 or higher.
  -}
 
+{-# LANGUAGE CPP #-}
+
 module Utility.Misc where
 
 import System.IO
 import Control.Monad
 import Foreign
 import Data.Char
+import Data.List
 import Control.Applicative
+#ifndef mingw32_HOST_OS
+import System.Posix.Process (getAnyProcessStatus)
+#endif
+
+import Utility.Exception
 
 {- A version of hgetContents that is not lazy. Ensures file is 
  - all read before it gets closed. -}
@@ -30,10 +38,10 @@ readFileStrict = readFile >=> \s -> length s `seq` return s
  -}
 separate :: (a -> Bool) -> [a] -> ([a], [a])
 separate c l = unbreak $ break c l
-	where
-		unbreak r@(a, b)
-			| null b = r
-			| otherwise = (a, tail b)
+  where
+	unbreak r@(a, b)
+		| null b = r
+		| otherwise = (a, tail b)
 
 {- Breaks out the first line. -}
 firstLine :: String -> String
@@ -44,11 +52,11 @@ firstLine = takeWhile (/= '\n')
  - Segments may be empty. -}
 segment :: (a -> Bool) -> [a] -> [[a]]
 segment p l = map reverse $ go [] [] l
-	where
-		go c r [] = reverse $ c:r
-		go c r (i:is)
-			| p i = go [] (c:r) is
-			| otherwise = go (i:c) r is
+  where
+	go c r [] = reverse $ c:r
+	go c r (i:is)
+		| p i = go [] (c:r) is
+		| otherwise = go (i:c) r is
 
 prop_segment_regressionTest :: Bool
 prop_segment_regressionTest = all id
@@ -61,11 +69,28 @@ prop_segment_regressionTest = all id
 {- Includes the delimiters as segments of their own. -}
 segmentDelim :: (a -> Bool) -> [a] -> [[a]]
 segmentDelim p l = map reverse $ go [] [] l
-	where
-		go c r [] = reverse $ c:r
-		go c r (i:is)
-			| p i = go [] ([i]:c:r) is
-			| otherwise = go (i:c) r is
+  where
+	go c r [] = reverse $ c:r
+	go c r (i:is)
+		| p i = go [] ([i]:c:r) is
+		| otherwise = go (i:c) r is
+
+{- Replaces multiple values in a string.
+ -
+ - Takes care to skip over just-replaced values, so that they are not
+ - mangled. For example, massReplace [("foo", "new foo")] does not
+ - replace the "new foo" with "new new foo".
+ -}
+massReplace :: [(String, String)] -> String -> String
+massReplace vs = go [] vs
+  where
+
+	go acc _ [] = concat $ reverse acc
+	go acc [] (c:cs) = go ([c]:acc) vs cs
+	go acc ((val, replacement):rest) s
+		| val `isPrefixOf` s =
+			go (replacement:acc) vs (drop (length val) s)
+		| otherwise = go acc rest s
 
 {- Given two orderings, returns the second if the first is EQ and returns
  - the first otherwise.
@@ -93,6 +118,22 @@ hGetSomeString h sz = do
 	fp <- mallocForeignPtrBytes sz
 	len <- withForeignPtr fp $ \buf -> hGetBufSome h buf sz
 	map (chr . fromIntegral) <$> withForeignPtr fp (peekbytes len)
-	where
-		peekbytes :: Int -> Ptr Word8 -> IO [Word8]
-		peekbytes len buf = mapM (peekElemOff buf) [0..pred len]
+  where
+	peekbytes :: Int -> Ptr Word8 -> IO [Word8]
+	peekbytes len buf = mapM (peekElemOff buf) [0..pred len]
+
+{- Reaps any zombie git processes. 
+ -
+ - Warning: Not thread safe. Anything that was expecting to wait
+ - on a process and get back an exit status is going to be confused
+ - if this reap gets there first. -}
+reapZombies :: IO ()
+#ifndef mingw32_HOST_OS
+reapZombies = do
+	-- throws an exception when there are no child processes
+	catchDefaultIO Nothing (getAnyProcessStatus False True)
+		>>= maybe (return ()) (const reapZombies)
+
+#else
+reapZombies = return ()
+#endif
